@@ -229,6 +229,7 @@ def _insert_jos_users(db, joomlauserid, name, username, email, password, jgidNum
 
 	return userID
 
+
 def _insert_jos_core_acl_aro(db, userID, fullname):
 	sql = "INSERT INTO `jos_core_acl_aro` (`section_value`, `value`, `order_value`, `name`, `hidden`) "
 	sql += "VALUES (%s, %s, %s, %s, %s)"
@@ -236,17 +237,20 @@ def _insert_jos_core_acl_aro(db, userID, fullname):
 	aroID = db.query_lastrowid(sql, data)
 	return aroID
 
+
 def _insert_jos_core_acl_groups_aro_map(db, jgidNumber, aroID):
 	sql = "INSERT INTO `jos_core_acl_groups_aro_map` (`group_id`, `section_value`, `aro_id`) "
 	sql += "VALUES (%s, %s, %s)"
 	data = ( jgidNumber, '', aroID)
 	db.query_rowcount(sql, data)
 
+
 def _insert_jos_user_usergroup_map(db, userID, groupID = 2):
 	sql = "INSERT INTO `jos_user_usergroup_map` (`user_id`, `group_id`) VALUES (%s, %s)"
 	data = (userID, groupID)
 	db.query_rowcount(sql, data)
 
+
 def _insert_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, username, email, password, gid, gidNumber, loginShell, homeDir):
 
 	pw = hashPassword(password)
@@ -265,7 +269,7 @@ def _insert_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, username,
 	if rowCount == 1:
 		sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
 		sql += "`ftpShell`, `userPassword`, `gid`, `orgtype`, `organization`, `countryresident`, `countryorigin`, `gender`, `url`, `reason`, "
-		sql += "`mailPreferenceOption`, `usageAgreement`, , `jobsAllowed`, `modifiedDate`, `emailConfirmed`, `regIP`, `regHost`, `nativeTribe`, `phone`, "
+		sql += "`mailPreferenceOption`, `usageAgreement`, `jobsAllowed`, `modifiedDate`, `emailConfirmed`, `regIP`, `regHost`, `nativeTribe`, `phone`, "
 		sql += "`proxyPassword`, `proxyUidNumber`, `givenName`, `middleName`, `surname`, `picture`, `vip`, `public`, `params`, `note`, `shadowExpire`) "
 		sql += "VALUES (" + '%s,'*37 + "%s );" 
 
@@ -451,7 +455,7 @@ def addhubuser(hubname,
 			print "User '" + username + "' already exists in ldap"
 			return (2)
 	else:
-		print "skip cms insert and ldap, but then why bother?"
+		print "skip cms insert and ldap"
 		return(3)
 
 	# if the user doesn't want custom group for this user, they still need to be added to some group
@@ -692,7 +696,6 @@ def _syncuser(username, hubname = "", syncAttributes = False):
 		               attrsToSync)
 	else:
 		print "_syncuser cannot find info on username: " + username + " from the jos_users table"
-		
 
 		
 def add_ldap_user2(cn,
@@ -760,9 +763,11 @@ def add_ldap_user2(cn,
 def syncuser(user, hubname = "", purgeorphans = True, syncattributes = True, verbose = False, debug = False):
      _syncusers(hubname, purgeorphans, syncattributes, user, verbose, debug)
 
+
 def syncusers(hubname = "", purgeorphans = True, syncattributes = True, verbose = False, debug = False):
      _syncusers(hubname, purgeorphans, syncattributes, '*', verbose, debug)
 
+
 def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user = '*', verbose = False, debug = False):
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
@@ -849,7 +854,6 @@ def updateuser(username, hubname = "", fname="", mname="", lname="", email="", h
 	if homedir:  _update_ldap_user_attribue(username, 'homeDirectory', homedir)
 
 
-
 def _update_ldap_user_attribue(uid, attributename, attributevalue):
 
         hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
